import React from 'react';
import { useDispatch, useStore } from "react-redux";
import NotebookLumino from './NotebookLumino';
import LuminoAttached from '../../lumino/LuminoAttached';
import { notebookEpics, notebookActions, notebookReducer, selectNotebook } from './NotebookRedux';
import { asObservable } from '../../lumino/LuminoObservable';
import './Notebook.css';
import './extension/CellSidebar.css';
const Portals = () => {
    const notebook = selectNotebook();
    const portals = notebook.portals;
    return React.createElement(React.Fragment, null, portals.map((portal) => portal));
};
const Notebook = (props) => {
    const notebookLumino = new NotebookLumino();
    const store = useStore();
    const dispatch = useDispatch();
    notebookLumino.manager.ready.then(() => {
        notebookLumino.createApp(props.path);
        const notebookChange$ = asObservable(notebookLumino.notebookPanel.model.sharedModel.changed);
        notebookChange$.subscribe(notebookChange => {
            dispatch(notebookActions.notebookChange.started(notebookChange));
        });
        const activeCellChanged$ = asObservable(notebookLumino.notebookPanel.content.activeCellChanged);
        activeCellChanged$.subscribe(activeCellChanged => {
            dispatch(notebookActions.activeCellChange.started(activeCellChanged));
        });
        const kernelStatusChanged$ = asObservable(notebookLumino.notebookPanel.sessionContext.statusChanged);
        kernelStatusChanged$.subscribe(kernelStatusChanged => {
            dispatch(notebookActions.kernelStatusChanged.started(kernelStatusChanged));
        });
        store.injectReducer('notebook', notebookReducer);
        store.injectEpic(notebookEpics(notebookLumino));
    });
    return (React.createElement(React.Fragment, null,
        React.createElement(Portals, null),
        React.createElement(LuminoAttached, null, notebookLumino.panel)));
};
export default Notebook;
//# sourceMappingURL=Notebook.js.map