import React, { useState, useEffect, useRef } from 'react';
import { ReactWidget } from '@jupyterlab/apputils';
/**
 * The class name added to OutputPrompt.
 */
const INPUT_PROMPT_CLASS = 'jp-InputPrompt';
export default function Countdown(props) {
    const [count, setCount] = useState(props.count);
    let intervalRef = useRef();
    const decreaseNum = () => setCount((prev) => prev - 1);
    useEffect(() => {
        setCount(props.count);
    }, [props.count]);
    useEffect(() => {
        intervalRef.current = setInterval(decreaseNum, 1000);
        return () => clearInterval(intervalRef.current);
    }, []);
    return (React.createElement("div", null,
        React.createElement("div", null, count)));
}
/**
 * The custom input prompt implementation.
 */
export class NotebookInputPrompt extends ReactWidget {
    /*
    * Create an output prompt widget.
    */
    constructor() {
        super();
        this.state = {
            count: 100
        };
        this._executionCount = null;
        this.addClass(INPUT_PROMPT_CLASS);
    }
    render() {
        return React.createElement(Countdown, { count: this.state.count });
    }
    /**
     * The execution count for the prompt.
     */
    get executionCount() {
        return this._executionCount;
    }
    set executionCount(value) {
        this._executionCount = value;
        if (value === null) {
            this.state = {
                count: 0
            };
        }
        else {
            if (value === '*') {
                this.state = {
                    count: 0
                };
            }
            else {
                this.state = {
                    count: Number(value)
                };
                this.update();
            }
        }
    }
}
//# sourceMappingURL=PaperbookInputPrompt.js.map